From 8cf78b31b28b9183579c7939b947e1f7e9f5c2fa Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Thu, 12 Jan 2012 04:54:19 -0500
Subject: [PATCH] Merged revisions 2812-2883 from staböe branch.
---
install/install.php | 9 ++++++++-
1 files changed, 8 insertions(+), 1 deletions(-)
diff --git a/install/install.php b/install/install.php
index a31efbc..0255c12 100644
--- a/install/install.php
+++ b/install/install.php
@@ -102,8 +102,9 @@
//** Detect the installed applications
$inst->find_installed_apps();
//** Select the language
$conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
+$conf['timezone'] = 'UTC';
//** Select installation mode
$install_mode = $inst->simple_query('Installation mode', array('standard','expert'), 'standard');
@@ -127,6 +128,12 @@
$tmp_mysql_server_database = $inst->free_query('MySQL database to create', $conf['mysql']['database']);
$tmp_mysql_server_charset = $inst->free_query('MySQL charset', $conf['mysql']['charset']);
+ if($install_mode == 'expert') {
+ swriteln("The next two questions are about the internal ISPConfig database user and password.\nIt is recommended to accept the defaults which are 'ispconfig' as username and a random password.\nIf you use a different password, use only numbers and chars for the password.\n");
+ $conf['mysql']['ispconfig_user'] = $inst->free_query('ISPConfig mysql database username', $conf['mysql']['ispconfig_user']);
+ $conf['mysql']['ispconfig_password'] = $inst->free_query('ISPConfig mysql database password', $conf['mysql']['ispconfig_password']);
+ }
+
//* Initialize the MySQL server connection
if(@mysql_connect($tmp_mysql_server_host, $tmp_mysql_server_admin_user, $tmp_mysql_server_admin_password)) {
$conf['mysql']['host'] = $tmp_mysql_server_host;
@@ -102,8 +102,9 @@
//** Detect the installed applications
$inst->find_installed_apps();
-//** Select the language
+//** Select the language and set default timezone
$conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
--
Gitblit v1.9.1